# educelab-imgproc

EduceLab image processing module. Largely wrapper functions for encouraging
consistent use across multiple projects.

## Installation

```shell
python3 -m pip install educelab-imgproc
```